@@ -245,16 +245,16 @@ class ContextViewer(Columns):
             wrap = 'space' # Do not cut description and wrap content
             data = tounicode(ctx.description())
             if pygments:
-                lexer = lexers.RstLexer()
+                lexer = lexers.get_lexer_by_name('reStructuredText')
         else: # source content is a file
             wrap = 'clip' # truncate lines
             flag, data = self.manifest_walker.filedata(filename)
             lexer = None # default to inspect filename and/or content
             if flag == '=' and pygments: # modified => display diff
-                lexer = lexers.DiffLexer() if flag == '=' else None
+                lexer = lexers.get_lexer_by_name('diff') if flag == '=' else None
             elif flag == '-' or flag == '': # removed => just say it
                 if pygments:
-                    lexer = lexers.DiffLexer()
+                    lexer = lexers.lexer_by_name('diff')
                 data = '- Removed file'
             elif flag == '+': # Added => display content
                 numbering = True
