@@ -26,4 +26,4 @@ except ImportError:
 try:
     from mercurial.scmutil import revrange
 except ImportError:
-    revrange = lambda repo, rev: [repo.changectx(rev).rev()]
+    revrange = lambda repo, rev: [repo[rev].rev()]
