@@ -190,7 +190,7 @@ class FileViewer(AbstractFileDialog, ui2cls('fileviewer.ui'), _FileViewer):
 
     def revisionSelected(self, rev):
         pos = self.textView.verticalScrollBar().value()
-        ctx = self.filerevmodel.repo.changectx(rev)
+        ctx = self.filerevmodel.repo[rev]
         self.textView.setContext(ctx)
         self.textView.displayFile(self.filerevmodel.graph.filename(rev))
         self.textView.verticalScrollBar().setValue(pos)
@@ -343,7 +343,7 @@ class FileDiffViewer(AbstractFileDialog, ui2cls('filediffviewer.ui'), _FileDiffV
         else:
             side = 'left'
         path = self.filerevmodel.graph.nodesdict[rev].extra[0]
-        fc = self.repo.changectx(rev).filectx(path)
+        fc = self.repo[rev].filectx(path)
         self.filedata[side] = tounicode(fc.data()).splitlines()
         self.update_diff(keeppos=otherside[side])
 
