@@ -620,7 +620,7 @@ class HgRepoViewer(ActionsMixin, HgDialogMixin, ui2cls('hgqv.ui'), QtGui.QMainWi
                         (self.repo.root, ".hg", "dirstate"),
                         (self.repo.root, ".hg", "store", "phasesroots"),]
         watchedfiles = [os.path.join(*wf) for wf in watchedfiles]
-        for l in (self.repo.sjoin('lock'), self.repo.join('wlock')):
+        for l in (self.repo.sjoin('lock'), self.repo.vfs.join('wlock')):
             try:
                 if util.readlock(l):
                     break
@@ -685,7 +685,7 @@ class HgRepoViewer(ActionsMixin, HgDialogMixin, ui2cls('hgqv.ui'), QtGui.QMainWi
         sender = kw.get('sender') or self.sender()
         follow = kw.get('follow', False)
         closed = self.branch_checkBox_action.isChecked()
-        startrev = self.repo.changectx(startrev).rev()
+        startrev = self.repo[startrev].rev()
         self.repomodel.show_hidden = self.get_action('showhide').isChecked()
         self.repomodel.setRepo(self.repo, branch=branch, fromhead=startrev,
                                follow=follow, closed=closed)
